@@ -1,28 +1,17 @@
 #==============================================================================
 # Contains some Tk option database settings.
 #
-# Copyright (c) 2004-2019  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
+# Copyright (c) 2004-2023  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
 #==============================================================================
 
-#
-# Get the current windowing system ("x11", "win32", "classic", or "aqua")
-#
-if {[catch {tk windowingsystem} winSys] != 0} {
-    switch $::tcl_platform(platform) {
-	unix      { set winSys x11 }
-	windows   { set winSys win32 }
-	macintosh { set winSys classic }
-    }
-}
-
 #
 # Add some entries to the Tk option database
 #
-if {[string compare $winSys "x11"] == 0} {
+if {[tk windowingsystem] eq "x11"} {
     #
     # Create the font TkDefaultFont if not yet present
     #
-    catch {font create TkDefaultFont -family Helvetica -size -12}
+    catch {font create TkDefaultFont -family Helvetica -size 9}
 
     option add *Font			TkDefaultFont
     option add *selectBackground	#5294e2
